<!--
	title: FavDocの使い方
	keywords: FavDoc, 使い方
	description: このページでは、FavDocの使い方について解説します。
	template: ../Template/TemplateSample1.html
-->
# FavDoc

## FavDoc.exeとは
Markdownファイルを解析してHtmlファイルに変換する為のツールです。
基本的に通常のMarkDownの文法に従っていますが、まだ実装されていない部分や、一部独自拡張していたりします。
指定したフォルダを自動巡回して、ファイルコピーを行いながら、Markdownファイルをhtmlやphpなどに変換する為の補助ツール
[FavDocSite.exe](./FavDocSite.html "FavDocSite")も付属しています。

まだ開発中なので、**優しく使ってあげて**ください。


## FavDocの入手方法
[ここより](http://www.wabiapp.com/FavDoc/FavDoc_0.0.7.zip)FavDocのzipファイルを取得します。インストーラは提供していません。


### FavDoc.zipの構成
```
FavDoc
    /FavDoc.exe                  ← FavDoc実行ファイル
    /FavDocSite.exe              ← FavDocSite実行ファイル
    /readme.txt                  ← 解説テキスト

    /FavDocSample
        /Template
            TemplateSample1.html ← テンプレート
        /Markdown
            /css                 ← css
            /images              ← 画像
            /SyntaxhigHlighter   ← SyntaxHighlighterインストール位置
        make.bat                 ← サンプル実行バッチファイル
        makeSyntax.bat           ← サンプル実行バッチファイル(SyntaxHighlighter版)

    /FavDocSiteSample
	    /make.bat                ← サンプル実行バッチファイル
        /Template                ← Configファイルとテンプレート
        /Markdown
            /css                 ← css
            /images              ← 画像
            /FavDoc.md           ← マニュアル(FavDoc.exe)
            /FavDoc2.md          ← マニュアル(FavDoc.exe)
            /FavDocSite.md       ← マニュアル(FavDocSite.exe)
```


## コマンドラインオプション
|オプション     |意味                                     |
|:--------------|:----------------------------------------|
|               | 入力ファイル                            |
| -o			| 出力ファイル                            |
| -t			| テンプレートファイル                    |
| -root			| ルートフォルダ                          |
| -?			| 使い方                                  |
| -syntax		| **(独自拡張)**Syntaxhighlighterフォルダ |
| -imagelink	| **(独自拡張)**Imageタグに自動的にタグのリンクを追加します。 |
| -ext			| **(独自拡張)**出力拡張子はMarkdownに従います。 |

## 使用例
```
> FavDoc.exe Test.md -o .\Test.html
```


## 独自拡張
* **Imageタグへの自動<A>タグリンク**  
コマンドラインオプションの```-imagelink```を指定すると、Imageタグに自動的に<a>タグのリンクを追加します。
* **\<pre>タグのSyntaxHighlighter対応**  
\<pre>タグで囲まれた部分をSyntaxHighlighterで修飾させる事ができます。
* **テンプレート**  
テンプレートとしてhtmlやphpなどを用意しておき、そのテンプレートに特定のキーワードを書いておくと、キーワード部分を解析結果に置き換えてくれます。


##\<pre>タグのSyntaxHighlighter対応
-syntax でSyntaxhighlighterのあるフォルダを指定しておきます。
code指定"\`\`\`"の後に言語へのエイリアス名を指定します。


````
``` cpp
SyntexHighlighter対応します。
SyntexHighlighter対応します。
SyntexHighlighter対応します。
SyntexHighlighter対応します。
```
````

### 使用例(SyntaxHighlighter利用時)
```
> FavDoc.exe Test.md -o .\Test.html -t .\Template.html -syntex .\SyntaxHighlighter
```


## テンプレート対応
コマンドラインオプションとして、テンプレート(htmlやphpなど)を指定しておくと、テンプレート中に特定のキーワード
(####BODY####など)を記載してけば、解析結果がキーワードと置き換わります。

|置き換えキーワード  |意味                                                 |
|:-------------------|:----------------------------------------------------|
|####ROOT####        | ルートフォルダへの相対パスに置き換わります          |
|####BODY####        | Markdownの解析結果のHtmlに置き換えられます。        |
|####SYNTAX####      | SyntaxHighlightのスクリプトリンクに置き換えられます |
|####TITLE####       | 独自拡張(title)に置き換えられます                   |
|####KEYWORDS####    | 独自拡張(keywords)に置き換えられます                |
|####DESCRIPTION#### | 独自拡張(description)に置き換えられます             |


## テンプレートサンプル
``` html
<!doctype html>
<html>
<head>
<meta charset="UTF-8"> 
<meta http-equiv="content-language" content="ja"> 
<meta name="author" content="作者">
<meta name="copyright" content="著作権、コピーライト">
<meta name="keywords" content="####KEYWORDS####">
<meta name="description" content="####DESCRIPTION####"> 
<link type="text/css" rel="stylesheet" href="####ROOT####/syntaxhighlighter/styles/shCoreDefault.css"/>
####SYNTAX####
<title>####TITLE####</title>
<style>
h1 {
	border-left: 8px solid gray;
	border-bottom: 1px solid gray;
	padding-left: 0.5em;
	margin-top: 2em;
}
h2 {
	border-left: 4px solid gray;
	padding-left: 0.5em;
	margin-top: 1em;
}
p, pre, table {
	margin-left: 1em;
}
li {
	margin-bottom: 1em;
}
table {
	border-collapse: collapse;
}
th {
	background-color: #8080ff;
	padding: 0em 0.5em;
}
table, th, td {
	border: 1px #808080 solid;
}
pre {
	background-color: lightgray;
	padding: 0.5em;
}
img {
	max-width: 100%;
}
code {
	background-color: lightgray;
}
</style>
<script>
</script>
</head>
<body>
####BODY####
</body>
</html>
```


# コメントタグによる独自拡張
Markdownファイルの中に、コメントタグで以下の情報を設定できます。

```
<!--
	title       : タイトル
	keywords    : キーワード
	description : サイトの説明
	template    : ../template2.html
-->
```

### 複数のコメントでも指定できます。
```
<!-- title: タイトル -->
<!-- keywords: キーワード -->
<!-- description: サイトの説明 -->
<!-- template: ../template2.html -->
```


## 意味
* **title**  
タイトルタグに関する情報を設定する事ができます。テンプレートの####TITLE####を置き換えます。
* **keywords**  
metaタグのkeywordsに関する情報を設定する事ができます。テンプレートの####KEYWORDS####を置き換えます。
* **description**  
metaタグのdescriptionに関する情報を設定する事ができます。テンプレートの####DESCRIPTION####を置き換えます。
* **template**  
コマンドラインの-tオプションでテンプレートを指定できますが、Markdown側からもテンプレートを指定する事ができるようになりました。コマンドラインで指定されたテンプレートよりも、こちらが優先されます。
テンプレートファイルのパスは、Markdownファイルが配置されている位置からの相対パスで指定します。

#SyntaxHighlighterの入手／設定方法

[SyntaxHighlighterの入手／設定方法](./FavDoc2.html)


